Enum SignError
pub enum SignError {
Serialize {
source: SerializationError,
},
Signing {
source: Box<dyn Error + Sync + Send>,
},
}Expand description
Error type returned when signing using Signable to sign data
Variants
Serialize
Error that occurs when serializing to sign over the bytes.
Fields

source: SerializationErrorUnderlying error source
Signing
Error that occurs when actually signing the data