Enum Signature
pub enum Signature {
Ed25519(SignatureScheme),
Passkey(SignatureScheme),
Multisig(SignatureScheme),
}Expand description
A generic signature
Each variant contains a signature scheme, which itself contains all the necessary data to verify the signature.
Variants
Ed25519(SignatureScheme)
Ed25519 signature
Passkey(SignatureScheme)
Passkey signature
Multisig(SignatureScheme)
Multisig signature
Implementations
impl Signature
impl Signature
pub fn verify(&self, data: &impl Serialize) -> Result<(), SignatureError>
pub fn verify(&self, data: &impl Serialize) -> Result<(), SignatureError>
Verifies the signature
pub fn verify_serialized(
&self,
bytes: impl AsRef<[u8]>,
) -> Result<(), SignatureError>
pub fn verify_serialized( &self, bytes: impl AsRef<[u8]>, ) -> Result<(), SignatureError>
Verify the signature against serialized bytes. Used in the context of canonical serialization to decouple serialization from verifying signatures.