Struct PubKey
pub struct PubKey { /* private fields */ }Expand description
Represents the public parameters of a multisignature authotization policy.
Defines the weight each key is associated with, and the minimal threshold above which a subset of signers can emit a valid signature.
Each PubKey defines a unique owner.
Implementations
impl PubKey
impl PubKey
pub const fn new(signers: BTreeMap<OwnerId, u64>, threshold: u64) -> PubKey
pub const fn new(signers: BTreeMap<OwnerId, u64>, threshold: u64) -> PubKey
Construct a new multisig account from its parts
pub const fn signers(&self) -> &BTreeMap<OwnerId, u64>
pub const fn signers(&self) -> &BTreeMap<OwnerId, u64>
Returns the signers and their associated weights
pub fn get_weight(&self, id: &OwnerId) -> Option<u64>
pub fn get_weight(&self, id: &OwnerId) -> Option<u64>
Returns the weight associated with the given id. Returns None if the id is not found in the owner list.