BaseSignedMessage

Struct BaseSignedMessage 

pub struct BaseSignedMessage<D, S> { /* private fields */ }
A basic container for signed messages, parameterized by payload and signature types.

This struct is designed to represent any message or data structure that has been signed, regardless of the underlying cryptographic scheme or the type of data being signed.

Usage

BaseSignedMessage is typically not used directly, but rather through a type alias like SignedMessage (for the polyvalent Signature scheme).

Implementations



impl<D, S> BaseSignedMessage<D, S>

pub const fn payload(&self) -> &D

Return a reference to the payload.

pub fn into_payload(self) -> D

Consume this message and return the payload by value.

pub const fn signature(&self) -> &S

Return a reference to the signature.

pub fn sign_preserving_type<K>( payload: D, signer: &K, ) -> Result<BaseSignedMessage<D, <K as SigningKey>::Signature>, SignError>
where K: SigningKey, D: Signable<K>,

Creates a new SignedMessage by signing the provided message with the given SigningKey.

Arguments
  • payload - data to be signed
  • signer - private key to sign the message with


impl<D> BaseSignedMessage<D, Signature>

pub const fn from_multisig_parts( payload: D, signature: SignatureScheme, ) -> BaseSignedMessage<D, Signature>

Create a new signed message from a multisig::SignatureScheme



impl<D> BaseSignedMessage<D, Signature>

pub fn sign<K>( payload: D, signer: &K, ) -> Result<BaseSignedMessage<D, Signature>, SignError>

Creates a new SignedMessage by signing the provided message with a SigningKey.