Enum SdlStatus
#[repr(i32)]pub enum SdlStatus {
Unproven = 0,
FullyProven = 1,
Failure = 2,
}Variants
Implementations
impl SdlStatus
impl SdlStatus
pub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
pub fn from_str_name(value: &str) -> Option<SdlStatus>
pub fn from_str_name(value: &str) -> Option<SdlStatus>
Creates an enum from field names used in the ProtoBuf definition.