Struct SDLProof
pub struct SDLProof { /* private fields */ }Expand description
Proof of valid State Diff List (SDL)
Implementations
impl SDLProof
impl SDLProof
pub const fn new(
id: HashDigest,
shard: u64,
bytes: Vec<u8>,
local_laws_vkey: Option<HashDigest>,
) -> SDLProof
pub const fn new( id: HashDigest, shard: u64, bytes: Vec<u8>, local_laws_vkey: Option<HashDigest>, ) -> SDLProof
Creates a new SDL proof for the SDL referenced by id.
Parameters
id- identifier of the proven SDLshard- shard the SDL applies tobytes- raw bytes of the prooflocal_laws_vkey- optionally the verification key of the local laws applying to this domain
pub const fn id(&self) -> HashDigest
pub const fn id(&self) -> HashDigest
Returns the identifier of the SDL this proof belongs to
pub const fn local_laws_vkey(&self) -> Option<HashDigest>
pub const fn local_laws_vkey(&self) -> Option<HashDigest>
Returns the verification key of the local laws proved by this proof (if any).