Struct StateDiffList
pub struct StateDiffList {
pub shard: u64,
pub diff: AggregatedStateDiff,
pub external_dependencies: BTreeSet<HashDigest>,
}Expand description
State diff list, i.e., what is submitted to the network with a SubmitStateDiffType transaction
Fields
shard: u64Shard this state diff list applies to
diff: AggregatedStateDiffActual diffs of the corresponding vaults
external_dependencies: BTreeSet<HashDigest>Hashes of the SDLs that this SDL depends on
Implementations
impl StateDiffList
impl StateDiffList
pub fn credited_shards(&self) -> HashSet<u64>
pub fn credited_shards(&self) -> HashSet<u64>
Returns the set of credited shards from this SDL