Struct TransactionBundle
pub struct TransactionBundle<T>where
T: TransactionType,{
pub transactions: Vec<SignedTransaction<T>>,
}Expand description
A bundle of (signed) transactions of type T.
Fields
transactions: Vec<SignedTransaction<T>>Collection of transactions.
Implementations
impl<T> TransactionBundle<T>where
T: TransactionType,
impl<T> TransactionBundle<T>where
T: TransactionType,
pub const fn new(
transactions: Vec<SignedTransaction<T>>,
) -> TransactionBundle<T>
pub const fn new( transactions: Vec<SignedTransaction<T>>, ) -> TransactionBundle<T>
Creates a new bundle with the given transactions.
pub const fn empty() -> TransactionBundle<T>
pub const fn empty() -> TransactionBundle<T>
Creates a new empty bundle.
pub fn add_transaction(&mut self, transaction: SignedTransaction<T>)
pub fn add_transaction(&mut self, transaction: SignedTransaction<T>)
Adds a transaction to the bundle.
pub fn add_transactions(
&mut self,
transactions: impl IntoIterator<Item = SignedTransaction<T>>,
)
pub fn add_transactions( &mut self, transactions: impl IntoIterator<Item = SignedTransaction<T>>, )
Adds a sequence of transactions to the bundle.
pub fn validate(&mut self) -> Vec<(HashDigest, TransactionValidationError)>
pub fn validate(&mut self) -> Vec<(HashDigest, TransactionValidationError)>
Run self-validations for each transaction in the bundle, removing transactions from the bundle if they fail the validation. The removed transactions are returned with the corresponding error.