Struct DomainAgreement
pub struct DomainAgreement { /* private fields */ }Expand description
Domain Agreement struct that defines the terms of service between a domain operator and the delta network.
Implementations
impl DomainAgreement
impl DomainAgreement
pub const fn new(
operator: PubKey,
shard: NonZero<u64>,
local_laws_vkey: Option<HashDigest>,
) -> DomainAgreement
pub const fn new( operator: PubKey, shard: NonZero<u64>, local_laws_vkey: Option<HashDigest>, ) -> DomainAgreement
Creates a new Domain Agreement
Arguments
operator- public key of the domain operatorshard- shard identifier of the domain (must be > 0)local_laws_vkey- verification key for the local laws applying to the domain
pub const fn local_laws_vkey(&self) -> Option<HashDigest>
pub const fn local_laws_vkey(&self) -> Option<HashDigest>
Returns the optional hash of the verifying key for the local laws of this domain