Struct TransactionFee
pub struct TransactionFee {
pub tip: u64,
}Expand description
The transaction fee structure for base layer transactions.
Currently, the fee structure only contains a tip amount to be fully consumed during transaction processing.
Fields
tip: u64The amount of plancks that constitute the tip to be paid by the transaction sender.