Enum VaultDataType
pub enum VaultDataType {
TokenHoldings(TokenHoldings),
FungibleTokenMint(Mint),
NftMint(Mint),
}Expand description
Available vault data types.
Variants
TokenHoldings(TokenHoldings)
Vault data type for token holdings.
FungibleTokenMint(Mint)
Vault data type for a fungible token mint.
NftMint(Mint)
Vault data type for an NFT mint.
Implementations
impl VaultDataType
impl VaultDataType
pub const fn token_mint(&self) -> Option<&Mint>
pub const fn token_mint(&self) -> Option<&Mint>
Get the mint
pub const fn is_fungible_mint(&self) -> bool
pub const fn is_fungible_mint(&self) -> bool
Returns true if the data is of type VaultDataType::FungibleTokenMint
pub const fn is_nft_mint(&self) -> bool
pub const fn is_nft_mint(&self) -> bool
Returns true if the data is of type VaultDataType::NftMint