Enum Operation
pub enum Operation {
Create(Mint),
IncreaseSupply(u64),
}Expand description
The type of operation that can be performed on a fungible Mint vault
Variants
Create(Mint)
Create a new token mint vault
IncreaseSupply(u64)
Increase the total supply of a token mint vault