Struct Mint
pub struct Mint {
pub collection: Collection,
}Expand description
Represents a NFT Mint, which is in first approximation a collection of NFTs
A NFT mint is the authority controlling a specific NFT collection in the protocol, maintaining its total supply and associated metadata
Fields
collection: CollectionThe collection being minted