Struct OwnerId
pub struct OwnerId(/* private fields */);Expand description
The public identity of any actor on the network.
This struct defines identity and ownership. It can only be derived from public keys of supported signing schemes.