Struct Vault
pub struct Vault { /* private fields */ }Expand description
Vault structure for domains that can hold native tokens, custom data, and non-native tokens.
Sharded vaults are more complex than base vaults - they support custom data storage and can hold both fungible and non-fungible tokens in addition to native tokens.
Implementations
impl Vault
impl Vault
pub const fn new(shard: NonZero<u64>) -> Vault
pub const fn new(shard: NonZero<u64>) -> Vault
Creates a new sharded vault on the specified shard.
The vault is initialized with zero balance and no custom data.
Parameters
shard- shard identifier for the new vault
Examples
use std::num::NonZero;
use delta_primitives::vault::sharded::{Vault, ReadableShardedVault};
let vault = Vault::new(NonZero::new(3).unwrap());
assert_eq!(vault.shard(), 3);Trait Implementations
impl<'de> Deserialize<'de> for Vault
impl<'de> Deserialize<'de> for Vault
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Vault, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Vault, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl ReadableNativeBalance for Vault
impl ReadableNativeBalance for Vault
impl ReadableShardedVault for Vault
impl ReadableShardedVault for Vault
fn data(&self) -> Option<&VaultDataType>
fn data(&self) -> Option<&VaultDataType>
Returns the custom data stored in the vault, if any.
fn token_balance(&self, kind: &TokenKind) -> u64
fn token_balance(&self, kind: &TokenKind) -> u64
Returns the balance of a specific token type in the vault. Read more
impl Serialize for Vault
impl Serialize for Vault
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl WritableNativeBalance for Vault
impl WritableNativeBalance for Vault
fn set_balance(&mut self, balance: u64)
fn set_balance(&mut self, balance: u64)
Sets the native token balance of the vault. Read more
fn checked_add_balance(&mut self, balance: u64) -> Result<(), VaultError>
fn checked_add_balance(&mut self, balance: u64) -> Result<(), VaultError>
Adds to the native token balance with overflow checking. Read more
fn checked_sub_balance(&mut self, balance: u64) -> Result<(), VaultError>
fn checked_sub_balance(&mut self, balance: u64) -> Result<(), VaultError>
Subtracts from the native token balance with underflow checking. Read more
fn saturating_add_balance(&mut self, balance: u64)
fn saturating_add_balance(&mut self, balance: u64)
Adds to the native token balance with saturation. Read more
fn saturating_sub_balance(&mut self, balance: u64)
fn saturating_sub_balance(&mut self, balance: u64)
Subtracts from the native token balance with saturation. Read more
impl WritableShardedVault for Vault
impl WritableShardedVault for Vault
fn set_data(&mut self, data: Option<VaultDataType>)
fn set_data(&mut self, data: Option<VaultDataType>)
Sets the custom data for the vault. Read more
fn apply_diff(&mut self, diff: &StateDiffOperation) -> Result<(), VaultError>
fn apply_diff(&mut self, diff: &StateDiffOperation) -> Result<(), VaultError>
Applies a state diff operation to the vault. Read more
fn set_token_balance(
&mut self,
token_kind: &TokenKind,
balance: u64,
) -> Result<(), VaultError>
fn set_token_balance( &mut self, token_kind: &TokenKind, balance: u64, ) -> Result<(), VaultError>
Sets the balance of a fungible token type in the vault. Read more
fn set_nft_holdings(
&mut self,
token_kind: &TokenKind,
balance: BTreeSet<u64>,
) -> Result<(), VaultError>
fn set_nft_holdings( &mut self, token_kind: &TokenKind, balance: BTreeSet<u64>, ) -> Result<(), VaultError>
Sets holdings of a specific NFT token in the vault. Read more
fn checked_add_token_balance(
&mut self,
token_kind: &TokenKind,
balance: u64,
) -> Result<(), VaultError>
fn checked_add_token_balance( &mut self, token_kind: &TokenKind, balance: u64, ) -> Result<(), VaultError>
Adds to a token balance with overflow checking. Read more
fn checked_sub_token_balance(
&mut self,
token_kind: &TokenKind,
balance: u64,
) -> Result<(), VaultError>
fn checked_sub_token_balance( &mut self, token_kind: &TokenKind, balance: u64, ) -> Result<(), VaultError>
Subtracts from a token balance with underflow checking. Read more
impl Eq for Vault
impl StructuralPartialEq for Vault