Enum Operation
pub enum Operation {
Create {
metadata: Metadata,
credited: Vec<Credit>,
},
IncreaseSupply {
credited: Vec<Credit>,
},
}Expand description
Represents operations that can be performed on a token’s supply.
This includes creating a new token with an initial supply or increasing the supply of an existing token.
The supply of the token is computed as the sum of all the credited accounts.
Variants
Create
Creates a new token with the specified metadata and credits the initial supply to the given vaults.
Fields
IncreaseSupply
Increases the supply of an existing token and credits it to the specified vaults.
Implementations