Payload

Struct Payload 

pub struct Payload<D> { /* private fields */ }
A payload wrapper containing both structured content and optional arbitrary bytes.

This is used by verifiable types (like SignedDebitAllowance) to include auxiliary data that is also signed, enabling Local Laws to prove things about signed messages.

Implementations



impl<D> Payload<D>

pub const fn new(content: D) -> Payload<D>

Create a new payload with empty auxiliary data.

pub const fn with_auxiliary(content: D, auxiliary: Vec<u8>) -> Payload<D>

Create a new payload with auxiliary data.

pub const fn content(&self) -> &D

Returns the content of the payload.

pub const fn auxiliary(&self) -> &Vec<u8>

Returns the auxiliary data of the payload.

pub fn into_signed<K>( self, signer: &K, ) -> Result<BaseSignedMessage<Payload<D>, Signature>, SignError>

Consume the payload and sign it with the given signer.