DomainBuilder

Struct DomainBuilder 

pub struct DomainBuilder<S> { /* private fields */ }
Builder to configure and create new domains

Obtain an instance via Domain::builder or Domain::from_config, then configure the domain with, for example:

Finally, call build to create the Domain.

Implementations

Source

impl<S> DomainBuilder<S>

pub fn with_rocksdb(self, db_options: DbOptions) -> DomainBuilder<DbOptions>

Use RocksDb with the given configuration as storage

Source

impl DomainBuilder<DbOptions>

pub async fn build(self) -> Result<Domain<Storage>, Error>

Build the domain to get its handles.

Source

impl<S> DomainBuilder<S>

pub fn with_proving_client(self, proving: Box<dyn Proving>) -> Self

Use the given proving client to generate proofs.

This can be a custom implementation of Proving or a provided one, for example SP1 (the sp1 feature needs to be active for that):

use delta_domain_sdk::{proving, Domain};

builder.with_proving_client(
    Box::new(proving::sp1::Client::global_laws_cpu()
        .with_local_laws_cpu(local_laws_elf))
);
pub fn with_storage<S2>(self, storage: S2) -> DomainBuilder<Database<S2>>
where S2: KeyValueStorageWithColumnFamilies<ColumnFamilyIdentifier = ColumnFamilies, Error = StorageError> + Send + Sync + 'static,

Use a custom KeyValueStorageWithColumnFamilies implementation

Note

The SDK assumes that iteration order for [ColumnFamilies::PendingVerifiables] (i.e. the column family) is in lexicographical order of the keys/indices.

pub fn with_database<S2>( self, database: Database<S2>, ) -> DomainBuilder<Database<S2>>
where S2: KeyValueStorageWithColumnFamilies<ColumnFamilyIdentifier = ColumnFamilies, Error = StorageError> + Send + Sync + 'static,

Use a custom KeyValueStorageWithColumnFamilies implementation wrapped in a Database.

Note

The SDK assumes that iteration order for [ColumnFamilies::PendingVerifiables] (i.e. the column family) is in lexicographical order of the keys/indices.

pub fn with_rpc(self, url: impl TryInto<Uri, Error = InvalidUri> + Send) -> Self

Use an RPC to connect to the base layer network.

Parameters
  • url - of the base layer RPC
pub fn with_mock_rpc(self, mock_vaults: HashMap<Address, Vault>) -> Self

Override any previously configured RPC (even rpc_url from config file) and use a mock RPC as base layer network that can return the given mock_vaults when requested.

Note that only sharded vaults are supported.

Source

impl<S> DomainBuilder<Database<S>>
where S: KeyValueStorageWithColumnFamilies<ColumnFamilyIdentifier = ColumnFamilies, Error = StorageError> + Send + Sync + 'static,

pub async fn build(self) -> Result<Domain<S>, Error>

Build the domain to get its handles.