pub struct ConfigFile {
pub shard: Shard,
pub keypair: PathBuf,
pub rpc_url: Option<String>,
pub storage: Option<StorageConfig>,
pub admin_api: Option<SocketAddr>,
pub proving: Option<ConfigFile>,
pub signature_verification: Option<SignatureVerificationConfig>,
}Expand description
Contents of the domain configuration file
Configuration files can be written in one of the allowed formats and are read with Config::load.
Fields
shard: ShardShard number this domain operates on
keypair: PathBufPath to a JSON file containing the (ed25519) keypair the domain signs transactions with.
This PathBuf value, when indicating a relative path, is relative to the location of the configuration file.
rpc_url: Option<String>URL of the base layer RPC to connect to. If none, a mock RPC is used.
storage: Option<StorageConfig>Storage path. This is ignored when not using the rocksdb feature
admin_api: Option<SocketAddr>Admin API listen address. This is ignored when not using the admin-api feature
proving: Option<ConfigFile>Proving configuration (global_laws, local_laws), ELF not yet resolved.
signature_verification: Option<SignatureVerificationConfig>Signature verification config