Enum SdlState
pub enum SdlState {
Submitted,
Proving,
Proven,
ProofSubmitted,
BaseLayerApplied,
BaseLayerFailed,
ProvingFailed(String),
}Expand description
The state an SDL can reach on the local-state.
Variants
Submitted
SDL was (successfully) submitted to the base layer
Proving
State when proof generation has started
Proven
State when proof generation completed successfully
ProofSubmitted
State when proof was successfully submitted to the base layer
BaseLayerApplied
State when the SDL proof was applied on the base layer After this state, it is impossible to rollback this SDL.
BaseLayerFailed
State when SDL failed to be applied on the base-layer
ProvingFailed(String)
State when proof generation failed with error message