Struct LocalLawsProverConfigFile
pub struct LocalLawsProverConfigFile {
pub program: PathBuf,
}Expand description
Configuration of a prover with the program that needs to be proven
The ProverConfig for the local laws is the same as the prover config of the global laws.
Fields
program: PathBufPath to the ELF containing the program to be proven
This PathBuf value, when indicating a relative path, is relative to the location of the configuration file.