DomainStateView

Struct DomainStateView 

pub struct DomainStateView<Db> { /* private fields */ }
Helper to access the domain state view of the vaults on this shard

Implementations

Source

impl<Db> DomainStateView<Db>
where Db: DbQueriesPort,

pub fn get_vault(&self, owner: &OwnerId) -> Result<Option<Vault>, Error>

Get the domain state view of the Vault of owner.

The domain state view is potentially the ahead of the finalized state. All verifiables applied to the domain are already visible on the vault.

Parameters
  • owner - The ID of the vault owner
Returns
  • Ok(Some(vault)) - If the vault exists (in domain view or finalized state)
  • Ok(None) - If no vault exists for the given owner (not even in finalized state)
  • Err(error) - If a storage error occurred
pub fn next_nonce(&self, owner: &OwnerId) -> Result<Nonce, Error>

Get the next nonce for the local vault at owner.

The next verifiable to debit the vault of owner must use the returned nonce in order to be valid.

Parameters
  • owner - The ID of the vault owner