Sdls

Struct Sdls 

pub struct Sdls<Db> { /* private fields */ }
Helper to access the SDL state

Implementations

Source

impl<Db> Sdls<Db>
where Db: DbQueriesPort,

pub fn get_status(&self, sdl_id: &SdlId) -> Result<Option<SdlState>, Error>

Get the current status of a State Diff List (SDL) that was processed by this domain.

Parameters
  • sdl_id - The id of the SDL to query
Returns
  • Ok(Some(state)) - The current state of the SDL if found
  • Ok(None) - If no SDL with the given id exists
  • Err(Error) - If there was an error reading from storage
pub fn get_all(&self) -> Result<Vec<(SdlId, SdlState)>, Error>

Get all State Diff List (SDL) ids with their current status

pub fn get_proof_transaction_id( &self, sdl_id: &SdlId, ) -> Result<Option<TxId>, Error>

Get the TxId of the base layer transaction that submitted the proof of the SDL identified by the given SdlId.

Returns
  • Ok(Some(tx_id)) - The requested TxId if found
  • Ok(None) - If no TxId was registered for the given SDL id, e.g. the proof was not yet submitted
  • Err(Error) - If there was an error reading from storage