Views

Struct Views 

pub struct Views<S = Storage>
where S: KeyValueStorageWithColumnFamilies<ColumnFamilyIdentifier = ColumnFamilies, Error = StorageError> + Send + Sync + 'static,
{ /* private fields */ }
Read-only views to read state and data from the domain.

The views are initialized by running the domain. Be sure to do that first and wait for initialization to finish (run_in_background can help for this).

Cloneable and can be shared across tasks.

Implementations

Source

impl<S> Views<S>
where S: KeyValueStorageWithColumnFamilies<ColumnFamilyIdentifier = ColumnFamilies, Error = StorageError> + Send + Sync + 'static,

pub const fn domain_view(&self) -> &DomainStateView<Database<S>>

Access the domain state view

pub const fn finalized(&self) -> &FinalizedState<Database<S>, BaseLayer>

Access the finalized state

pub const fn sdls(&self) -> &Sdls<Database<S>>

Access the SDL status

pub const fn verifiables(&self) -> &Verifiables<Database<S>>

Access the verifiable status and data