pub enum BaseLayerEvent {
NewEpoch(u64),
SdlUpdate(SdlUpdate),
VaultEmigrated(Address),
VaultImmigrated(Address),
}Expand description
Event emitted by the base layer to notify clients of state changes
Base layer events are used to communicate important state changes to clients (e.g. domains). They are streamed from the base layer via RPC and allow clients to react to changes in the network.
Example
use delta_base_sdk::{events::BaseLayerEvent, rpc::BaseRpcClient};
async fn handle_events() -> Result<(), Box<dyn std::error::Error>> {
let client = BaseRpcClient::new("http://localhost:50051").await?;
let shard_id = 1;
// Subscribe to events for a specific shard
let mut event_stream = client.stream_base_layer_events(shard_id).await?;
// Process events as they arrive
while let Some(event_result) = event_stream.next().await {
match event_result {
Ok(event) => match event {
BaseLayerEvent::NewEpoch(epoch) => {
println!("New epoch started: {}", epoch);
},
BaseLayerEvent::SdlUpdate(update) => {
println!("SDL update received: {:?}", update.id);
},
BaseLayerEvent::VaultEmigrated(address) => {
println!("Vault emigrated: {address}");
},
BaseLayerEvent::VaultImmigrated(address) => {
println!("Vault immigrated: {address}");
},
},
Err(e) => eprintln!("Error receiving event: {e}"),
}
}
Ok(())
}Variants
NewEpoch(u64)
A new epoch has started in the network
This event is emitted when the network transitions to a new epoch.
SdlUpdate(SdlUpdate)
Update on a StateDiffList status
Notification about a SDL’s status change, including acceptance or rejection. This event can also be received when another domain submits an SDL crediting our shard.
VaultEmigrated(Address)
A vault has migrated away from the subscribed domain
This event indicates that the vault with the specified Address is now emigrated and registered with another domain.
VaultImmigrated(Address)
A vault has migrated into the subscribed domain
This event indicates that the vault with the specified Address is now immigrated and registered with this domain.