Struct DebitAllowance
pub struct DebitAllowance {
pub credited: Address,
pub allowances: BTreeMap<TokenKind, AllowanceAmount>,
pub new_nonce: u64,
pub debited_shard: u64,
}Expand description
A debit allowance.
It defines the vault to be credited, and the debited vault is computed using the signer’s ID and the debited shard.
The allowances field defines the maximum amount that can be debited per token kind.
Fields
credited: AddressAddress of the vault that is credited.
allowances: BTreeMap<TokenKind, AllowanceAmount>A map of asset debit allowances.
new_nonce: u64The new nonce for the debited vault.
debited_shard: u64The shard of the debited vault.