VerifiableType

Enum VerifiableType 

pub enum VerifiableType {
    DebitAllowance(BaseSignedMessage<Payload<DebitAllowance>, Signature>),
    FungibleTokenMint(BaseSignedMessage<Payload<Mint>, Signature>),
    NftMint(BaseSignedMessage<Payload<Mint>, Signature>),
}
All operations that verifiably satisfy global rules and can be translated to state diffs are part of this enum.

Variants



DebitAllowance(BaseSignedMessage<Payload<DebitAllowance>, Signature>)

Debit allowance type.



FungibleTokenMint(BaseSignedMessage<Payload<Mint>, Signature>)

New Token Mint type.



NftMint(BaseSignedMessage<Payload<Mint>, Signature>)

NFT mint type

Implementations



impl VerifiableType

pub fn is_debit_allowance(&self) -> bool

Returns true if this is a VerifiableType::DebitAllowance, otherwise false

pub fn as_debit_allowance_mut( &mut self, ) -> Option<&mut BaseSignedMessage<Payload<DebitAllowance>, Signature>>

Optionally returns mutable references to the inner fields if this is a VerifiableType::DebitAllowance, otherwise None

pub fn as_debit_allowance( &self, ) -> Option<&BaseSignedMessage<Payload<DebitAllowance>, Signature>>

Optionally returns references to the inner fields if this is a VerifiableType::DebitAllowance, otherwise None

pub fn into_debit_allowance( self, ) -> Result<BaseSignedMessage<Payload<DebitAllowance>, Signature>, VerifiableType>

Returns the inner fields if this is a VerifiableType::DebitAllowance, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_debit_allowance_unchecked( self, ) -> BaseSignedMessage<Payload<DebitAllowance>, Signature>

Unchecked return of the inner fields of VerifiableType::DebitAllowance.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_debit_allowance_unchecked( &self, ) -> &BaseSignedMessage<Payload<DebitAllowance>, Signature>

Unchecked reference of the inner fields of VerifiableType::DebitAllowance.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_debit_allowance_mut_unchecked( &mut self, ) -> &mut BaseSignedMessage<Payload<DebitAllowance>, Signature>

Unchecked mutable reference of the inner fields of VerifiableType::DebitAllowance.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_fungible_token_mint(&self) -> bool

Returns true if this is a VerifiableType::FungibleTokenMint, otherwise false

pub fn as_fungible_token_mint_mut( &mut self, ) -> Option<&mut BaseSignedMessage<Payload<Mint>, Signature>>

Optionally returns mutable references to the inner fields if this is a VerifiableType::FungibleTokenMint, otherwise None

pub fn as_fungible_token_mint( &self, ) -> Option<&BaseSignedMessage<Payload<Mint>, Signature>>

Optionally returns references to the inner fields if this is a VerifiableType::FungibleTokenMint, otherwise None

pub fn into_fungible_token_mint( self, ) -> Result<BaseSignedMessage<Payload<Mint>, Signature>, VerifiableType>

Returns the inner fields if this is a VerifiableType::FungibleTokenMint, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_fungible_token_mint_unchecked( self, ) -> BaseSignedMessage<Payload<Mint>, Signature>

Unchecked return of the inner fields of VerifiableType::FungibleTokenMint.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_fungible_token_mint_unchecked( &self, ) -> &BaseSignedMessage<Payload<Mint>, Signature>

Unchecked reference of the inner fields of VerifiableType::FungibleTokenMint.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_fungible_token_mint_mut_unchecked( &mut self, ) -> &mut BaseSignedMessage<Payload<Mint>, Signature>

Unchecked mutable reference of the inner fields of VerifiableType::FungibleTokenMint.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_nft_mint(&self) -> bool

Returns true if this is a VerifiableType::NftMint, otherwise false

pub fn as_nft_mint_mut( &mut self, ) -> Option<&mut BaseSignedMessage<Payload<Mint>, Signature>>

Optionally returns mutable references to the inner fields if this is a VerifiableType::NftMint, otherwise None

pub fn as_nft_mint( &self, ) -> Option<&BaseSignedMessage<Payload<Mint>, Signature>>

Optionally returns references to the inner fields if this is a VerifiableType::NftMint, otherwise None

pub fn into_nft_mint( self, ) -> Result<BaseSignedMessage<Payload<Mint>, Signature>, VerifiableType>

Returns the inner fields if this is a VerifiableType::NftMint, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_nft_mint_unchecked( self, ) -> BaseSignedMessage<Payload<Mint>, Signature>

Unchecked return of the inner fields of VerifiableType::NftMint.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_nft_mint_unchecked( &self, ) -> &BaseSignedMessage<Payload<Mint>, Signature>

Unchecked reference of the inner fields of VerifiableType::NftMint.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_nft_mint_mut_unchecked( &mut self, ) -> &mut BaseSignedMessage<Payload<Mint>, Signature>

Unchecked mutable reference of the inner fields of VerifiableType::NftMint.

Safety

Results in undefined behavior when it is the incorrect variant.



impl VerifiableType

pub fn verifiable_id(&self) -> HashDigest

Returns a stable identifier for this verifiable based on its signature.

pub fn verify_signature(&self) -> Result<(), SignatureError>

Verify the signature of the contained signed message