Type Alias VerifiableId
pub type VerifiableId = HashDigest<Signature>;Expand description
A unique identifier for a verifiable message in the system.
The identifier corresponds to the hash of the verifiable’s signature.
Aliased Type
pub struct VerifiableId(/* private fields */);