Struct Client
pub struct Client { /* private fields */ }Expand description
Mock Proving Implementation
A non-cryptographic mock implementation of the Proving trait for testing
purposes. This proving client doesn’t actually generate valid proofs but
instead creates placeholders that have the correct structure.
The mock proving client is useful for developing, debugging and testing other components of the system without the overhead of real proof generation.
Note: The mock proving should NEVER be used in production environments where cryptographic validity of proofs is essential for security.
Implementations
impl Client
impl Client
pub const fn global_laws() -> Client
pub const fn global_laws() -> Client
Creates a new mock prover that just runs the global laws.
pub fn with_local_laws<L>(self) -> Clientwhere
L: LocalLaws,
pub fn with_local_laws<L>(self) -> Clientwhere
L: LocalLaws,
Adds verification of the provided local laws to the mock prover.