pub struct DbOptions { /* private fields */ }Expand description
Configuration options for the domain database
These options control where and how the database stores data on disk. They are primarily used with the RocksDB storage backend.
Implementations
Sourceimpl DbOptions
impl DbOptions
Sourcepub fn with_db_prefix_path(self, prefix_path: PathBuf) -> Self
pub fn with_db_prefix_path(self, prefix_path: PathBuf) -> Self
Sourcepub fn append_to_prefix_path(&mut self, path: &str)
pub fn append_to_prefix_path(&mut self, path: &str)
Append a path component to the database’s existing prefix path
This is useful for creating subdirectories for different shards or domain instances.
Parameters
path- Path component to append