pub struct Database<Storage: KeyValueStorage> { /* private fields */ }Expand description
A database abstraction for storing and retrieving domain data
This is a thin wrapper around a [KeyValueStorage] implementation that provides a more convenient interface for working with column families and ensures thread-safe access through Arc.
The database can be backed by different storage engines:
- In-memory storage (with the
in_memoryfeature) - RocksDB persistent storage (with the
rocksdbfeature)
Implementations