pub struct DomainStateView<Db> { /* private fields */ }Expand description
Helper to access the domain state view of the vaults on this shard
Implementations
Sourceimpl<Db> DomainStateView<Db>where
Db: DbQueriesPort,
impl<Db> DomainStateView<Db>where
Db: DbQueriesPort,
Sourcepub fn get_vault(&self, owner: &OwnerId) -> Result<Option<Vault>, Error>
pub fn get_vault(&self, owner: &OwnerId) -> Result<Option<Vault>, Error>
Get the domain state view of the Vault of owner.
The domain state view is potentially the ahead of the finalized state. All verifiables applied to the domain are already visible on the vault.
Parameters
owner- The ID of the vault owner
Returns
Ok(Some(vault))- If the vault exists (in domain view or finalized state)Ok(None)- If no vault exists for the given owner (not even in finalized state)Err(error)- If a storage error occurred