pub struct FinalizedState<Db, F> { /* private fields */ }Expand description
Helper to access the finalized state
Implementations
Sourceimpl<Db, F> FinalizedState<Db, F>where
Db: DbQueriesPort,
F: FetchVaultsInboundPort,
impl<Db, F> FinalizedState<Db, F>where
Db: DbQueriesPort,
F: FetchVaultsInboundPort,
Sourcepub async fn get_vault(&self, address: &Address) -> Result<Vault, Error>
pub async fn get_vault(&self, address: &Address) -> Result<Vault, Error>
Get the finalized state of the Vault with the given address.
The finalized state is the state as it is on the base layer, irreversible.
Vaults of this shard are retrieved from local storage while shard-external vaults are requested from the base layer.
Sourcepub async fn get_mint(&self, token: &TokenId) -> Result<Option<Mint>, Error>
pub async fn get_mint(&self, token: &TokenId) -> Result<Option<Mint>, Error>
Get the finalized state of the fungible::Mint for a given token.
Parameters
token- ID of the token
Returns
Ok(Some(mint))- If the token existsOk(None)- If the token doesn’t exist, i.e. there is a non-mint vault at that addressErr(error)- If an error occurred