pub struct Views<S = Storage>where
S: KeyValueStorageWithColumnFamilies<ColumnFamilyIdentifier = ColumnFamilies, Error = StorageError> + Send + Sync + 'static,{ /* private fields */ }Expand description
Read-only views to read state and data from the domain.
The views are initialized by running the domain. Be sure to do that first and wait for initialization to finish (run_in_background can help for this).
Cloneable and can be shared across tasks.
Implementations
Sourceimpl<S> Views<S>where
S: KeyValueStorageWithColumnFamilies<ColumnFamilyIdentifier = ColumnFamilies, Error = StorageError> + Send + Sync + 'static,
impl<S> Views<S>where
S: KeyValueStorageWithColumnFamilies<ColumnFamilyIdentifier = ColumnFamilies, Error = StorageError> + Send + Sync + 'static,
Sourcepub const fn domain_view(&self) -> &DomainStateView<Database<S>>
pub const fn domain_view(&self) -> &DomainStateView<Database<S>>
Access the domain state view
Sourcepub const fn finalized(&self) -> &FinalizedState<Database<S>, BaseLayer>
pub const fn finalized(&self) -> &FinalizedState<Database<S>, BaseLayer>
Access the finalized state
Sourcepub const fn verifiables(&self) -> &Verifiables<Database<S>>
pub const fn verifiables(&self) -> &Verifiables<Database<S>>
Access the verifiable status and data